==> integrit_2.03.02.orig.tar.gz: integrit-2.03.02.orig/acconfig.h <==
/*
integrit - file integrity verification system
Copyright (C) 2000, 2001 Ed L. Cashin

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

/* PROGNAME will be used in error messages, etc. */
#define	PROGNAME	"integrit"

/* version string lives in configure.in */
#undef	INTEGRIT_VERSION

/* define this for debugging runtime diagnostics to stderr */
#undef	DEBUG

/* define this to compile in memory-leak detection */
#undef	ELC_FIND_LEAKS

/* Define this if your system provides strstr */
#undef	HAVE_STRSTR

/* Define this if your system provides strerror */
#undef	HAVE_STRERROR

/* define this on a host with little-endian byte order */
#undef LITTLE_ENDIAN_HOST

/* define this on a host with big-endian byte order */
#undef BIG_ENDIAN_HOST

/* biggest file size in bytes that cdb-reading code will mmap */
#undef CDB_MMAP_MAX

/* ---------------- gnupg crypto support ------------ */
/* define when system provides typedef for byte */
#undef HAVE_BYTE_TYPEDEF
/* define when system provides typedef for byte */
#undef HAVE_USHORT_TYPEDEF
/* define when system provides typedef for byte */
#undef HAVE_ULONG_TYPEDEF
/* define when system provides typedef for byte */
#undef HAVE_U16_TYPEDEF
/* define when system provides typedef for byte */
#undef HAVE_U32_TYPEDEF

#undef HAVE_STDINT_H
#undef HAVE_INTTYPES_H

/* (end acconfig.h) */

@TOP@

==> integrit_3.02.00.orig.tar.gz: integrit-3.02.orig/acconfig.h <==
/*
integrit - file integrity verification system
Copyright (C) 2000, 2001, 2002 Ed L. Cashin

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

/* PROGNAME will be used in error messages, etc. */
#define	PROGNAME	"integrit"

/* version string lives in configure.in */
#undef	INTEGRIT_VERSION

/* define this for debugging runtime diagnostics to stderr */
#undef	DEBUG

/* define this to compile in memory-leak detection */
#undef	ELC_FIND_LEAKS

/* Define this if your system provides strstr */
#undef	HAVE_STRSTR

/* Define this if your system provides strerror */
#undef	HAVE_STRERROR

/* define this on a host with little-endian byte order */
#undef LITTLE_ENDIAN_HOST

/* define this on a host with big-endian byte order */
#undef BIG_ENDIAN_HOST

/* biggest file size in bytes that cdb-reading code will mmap */
#undef CDB_MMAP_MAX

/* ---------------- gnupg crypto support ------------ */
/* define when system provides typedef for byte */
#undef HAVE_BYTE_TYPEDEF
/* define when system provides typedef for byte */
#undef HAVE_USHORT_TYPEDEF
/* define when system provides typedef for byte */
#undef HAVE_ULONG_TYPEDEF
/* define when system provides typedef for byte */
#undef HAVE_U16_TYPEDEF
/* define when system provides typedef for byte */
#undef HAVE_U32_TYPEDEF

/* define when system provides stdint.h header */
#undef HAVE_STDINT_H

/* define when system provides inttypes.h header */
#undef HAVE_INTTYPES_H

/* (end acconfig.h) */

@TOP@
